using System.ComponentModel.DataAnnotations;
using System.Threading;
using MediatR;
using Todo.Core.Interfaces.Persistence;
using Todo.Core.Interfaces.User;

namespace Todo.Core.Application.Queries.Todos;

public record GetTodoByIdQuery([Required] string TodoId) : IRequest<TodoViewModel>
{
    internal class Handler : IRequestHandler<GetTodoByIdQuery, TodoViewModel>
    {
        private readonly ICurrentUserService _currentUserService;
        private readonly ITodoRepository _todoRepository;

        public Handler(ICurrentUserService currentUserService, ITodoRepository todoRepository)
        {
            _currentUserService = currentUserService;
            _todoRepository = todoRepository;
        }

        public async Task<TodoViewModel> Handle(GetTodoByIdQuery request, CancellationToken cancellationToken)
        {
            var userId = _currentUserService.GetUserId();
            var todo = await _todoRepository.GetTodoByIdAsync(request.TodoId);

            //if (todo.AuthorId != userId)
            //    throw new InvalidOperationException("User is not allowed to access todo");

            return TodoViewModel.From(todo);
        }
    }
}